[![Crossing Minds](https://static.crossingminds.com/img/logo.png)](https://crossingminds.com)

# Crossing Minds Data Science Python Library

Recommendation and personalization are simple ways to increase sales by making product suggestions to customers based on historical behavior. This can be applied not only to e-commerce but also to music, gaming, events, articles and more.

Crossing Minds is democratizing access to recent gains in artificial intelligence research by building the world’s best content recommendation platform.

[Documentation](https://docs.api.crossingminds.com/)


# Key Features

| Feature | Description |
| ------- | ----------- |
| [Deep Collaborative Filtering](https://docs.api.crossingminds.com/concepts/under-the-hood.html#concept-algorithms-deep-collaborative-filtering) | Pinpoint complex patterns to predict taste, in ways that go beyond matrix factorization |
| [Deep Content Extraction](https://docs.api.crossingminds.com/concepts/under-the-hood.html#concept-algorithms-deep-content-extraction) | Extract deep information from images or texts to generate meaningful recommendations of new items |
| [Semantic Graph Embedding](https://docs.api.crossingminds.com/concepts/under-the-hood.html#concept-algorithms-semantic-graph-embedding) | Leverage all available information to further increase the accuracy of the recommendations, enabling users to discover hidden gems |
